from django.conf import settings
from rest_framework.generics import ListAPIView
from arkindex.documents.models import Page, Act
from arkindex.documents.serializers.search import PageSearchResultSerializer, ActSearchResultSerializer
from arkindex.documents.search import search_pages_post, search_acts_post
from arkindex.project.mixins import SearchAPIMixin


class SearchAPIView(SearchAPIMixin, ListAPIView):
    """
    A base class for ES search views
    """


class PageSearch(SearchAPIView):
    """
    Search and list transcriptions inside pages
    """
    serializer_class = PageSearchResultSerializer
    template_path = 'elastic/search_nested.json'
    es_source = ['date_range']
    es_sort = ["volumes", "_score", ]
    es_index = settings.ES_INDEX_PAGES
    es_type = Page.INDEX_TYPE

    def post_process(self, *args, **kwargs):
        return search_pages_post(*args)


class ActSearch(SearchAPIView):
    """
    Search for acts containing a specific word
    within a specific period
    """
    serializer_class = ActSearchResultSerializer
    template_path = 'elastic/search_nested.json'
    es_source = ['date_range']
    es_sort = ["volumes", "_score", ]
    es_index = settings.ES_INDEX_ACTS
    es_type = Act.INDEX_TYPE

    def post_process(self, *args, **kwargs):
        return search_acts_post(*args)
