#!/usr/bin/env python3
from django.conf import settings
from ponos.management.base import PonosCommand
from arkindex.project.argparse import CorpusArgument
from arkindex.documents.models import MetaData, MetaType
from arkindex.documents.date_parser import DateParser
import logging

logging.basicConfig(
    format='%(asctime)s [%(levelname)s] %(message)s',
    level=logging.INFO,
)

logger = logging.getLogger(__name__)


class Command(PonosCommand):
    help = "Create fresh interpreted dates from metadatas"
    docker_image = settings.ARKINDEX_APP_IMAGE
    base_recipe = settings.PONOS_RECIPE

    def add_arguments(self, parser):
        super().add_arguments(parser)
        parser.add_argument(
            '--corpus',
            help='ID or part of the name of the corpus to fetch metadatas from',
            type=CorpusArgument(),
        )
        parser.add_argument(
            '--dry-run',
            action='store_true',
            default=False,
            help='Print number of dates to update',
        )

    def run(self, corpus=None, dry_run=False, **options):
        metadatas = MetaData.objects.filter(type=MetaType.Date)
        if corpus:
            metadatas = metadatas.filter(element__corpus_id=corpus.id)
        DateParser(metadatas).run(dry_run=dry_run)
