from arkindex.documents.models import MetaData, MetaType, DateType, InterpretedDate
from arkindex.documents.date_parser import parse_date
from django.test import TestCase


class TestInterpretedDate(TestCase):

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        cls.metadata = MetaData(name="date", type=MetaType.Date, value='1337-may')

    def test_date_str(self):
        interpreted_date = parse_date(self.metadata.value)
        self.assertEqual(1, len(interpreted_date))
        self.assertEqual('1337-05', str(interpreted_date[0]))

    def test_to_es_range(self):
        date_test_table = {
            InterpretedDate(
                year=1221,
                type=DateType.Exact,
                metadata=self.metadata
            ): {'gte': '1221', 'lt': '1221||+1y'},
            InterpretedDate(
                year=1350,
                month=2,
                type=DateType.Exact,
                metadata=self.metadata
            ): {'gte': '1350-02', 'lt': '1350-02||+1M'},
            InterpretedDate(
                year=1323,
                type=DateType.Lower,
                metadata=self.metadata
            ): {'gte': '1323'},
            InterpretedDate(
                year=1212,
                month=12,
                day=12,
                type=DateType.Lower,
                metadata=self.metadata
            ): {'gte': '1212-12-12'},
            InterpretedDate(
                year=1212,
                type=DateType.Upper,
                metadata=self.metadata
            ): {'lt': '1212||+1y'},
            InterpretedDate(
                year=700,
                type=DateType.Unknown,
                metadata=self.metadata
            ): {},
        }
        for interpreted_date, expected_range in date_test_table.items():
            self.assertEqual(interpreted_date.to_es_range(), expected_range)
