from arkindex.project.tests import FixtureAPITestCase
from arkindex.documents.models import Corpus
from django.urls import reverse
from rest_framework import status


class TestSearchApi(FixtureAPITestCase):

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        cls.private_corpus = Corpus.objects.create(name='private', public=False)

    def setUp(self):
        super().setUp()
        self.valid_params = (
            {'q': 'a', 'score': '.7'},
            {'q': 'one two', 'date_lte': '1333'},
            {'q': 'one two', 'date_gte': '1333-12'},
            {'q': 'one two', 'date_gte': '1333-12-02'},
            {'q': 'one', 'type': 'page'},
            {'q': 'cat', 'corpus': str(self.corpus.id), 'score': '0.9', 'date_lte': '1333-12-02'},
        )
        self.wrong_params = (
            {'q': ' ', 'score': '0.7'},
            {'q': 'one', 'score': '1.01'},
            {'q': 'that', 'score': 'null'},
            {'q': 'one two', 'date_lte': '1450-'},
            {'q': 'one two', 'date_lte': '1450-02-30'},
            {'q': 'one', 'type': 'wrongtype'},
            {'q': 'cat', 'corpus': 'not_even_an_uuid'},
            {'q': 'two', 'date_lte': '1450', 'date_gte': '1460'},
        )
        self.forbidden_params = (
            {'q': 'knowledge', 'corpus': self.private_corpus.id},
        )

    def test_search_api(self):
        """
        Check if different set of client-provided parameters are
        correctly handled by search api endpoint
        """
        for params in self.valid_params:
            response = self.client.get(reverse('api:act-search'), params)
            self.assertEqual(response.status_code, status.HTTP_200_OK)

        for params in self.wrong_params:
            response = self.client.get(reverse('api:act-search'), params)
            self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)

        for params in self.forbidden_params:
            response = self.client.get(reverse('api:act-search'), params)
            self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
